// -1 = none, 0 = restore last visited tabs, 1 = load selected session which is stored
pref("browser.tabs.extensions.startup_action_overlay",  -1);
pref("browser.tabs.extensions.startup_action_overlay.selected_session",  "");
pref("browser.tabs.extensions.startup_action_overlay.onece_per_day",  false);
pref("browser.tabs.extensions.startup_action_overlay.onece_per_day.last_time",  0);
pref("browser.tabs.extensions.startup_action_overlay.ignore_OpenURL_requests", true);
pref("browser.tabs.extensions.copy_recent_tabs",           false);
pref("browser.tabs.extensions.backup_tabs",                false);

pref("browser.tabs.extensions.session.save_blank_tab",     true);
pref("browser.tabs.extensions.reload_restored_session",    false);

pref("browser.tabs.extensions.undo_cache.backup.enabled",  false);
pref("browser.tabs.extensions.undo_cache.global",          20);
